*****************
Um passeio guiado
*****************

Esta seção é um passeio guiado pelo que está disponível no Sage. Para
diversos outros exemplos, veja "Construções em Sage", que tem como
objetivo responder à questão geral "Como eu construo ...?". Veja
também o "Sage Reference Manual", que possui centenas de outros
exemplos. Note que é também possível percorrer este tutorial no Sage
Notebook clicando no link ``Help``.

(Se você está acessando este tutorial no Sage Notebook, pressione
``shift-enter`` para processar qualquer célula de entrada. Você pode
até editar a célula antes de pressionar ``shift-enter``. Em alguns
Macs pode ser necessário pressionar ``shift-return`` em vez de
``shift-enter``.)

.. toctree::

   tour_assignment
   tour_help
   tour_algebra
   tour_plotting
   tour_functions
   tour_rings
   tour_linalg
   tour_polynomial
   tour_coercion
   tour_groups
   tour_numtheory
   tour_advanced
